@@ -4,7 +4,7 @@ package Array::Iterator::Circular;
 use strict;
 use warnings;
 
-our $VERSION = '0.11'; # VERSION
+our $VERSION = '0.12'; # VERSION
 
 use Array::Iterator;
 our @ISA = qw(Array::Iterator);
@@ -57,19 +57,21 @@ sub get_loop_count {
 sub getLoopCount { my $self = shift; $self->get_loop_count(@_) }
 
 1;
-#ABSTRACT: A subclass of Array::Iterator to allow circular iteration
+# ABSTRACT: A subclass of Array::Iterator to allow circular iteration
 
 __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Array::Iterator::Circular - A subclass of Array::Iterator to allow circular iteration
 
 =head1 VERSION
 
-version 0.11
+This document describes version 0.12 of Array::Iterator::Circular (from Perl distribution Array-Iterator), released on 2017-07-04.
 
 =head1 SYNOPSIS
 
@@ -101,6 +103,19 @@ This iterator will loop continuosly as long as C<next> or C<get_next> is called.
 
 =for Pod::Coverage .+
 
+=head1 ORIGINAL AUTHOR
+
+stevan little, E<lt>stevan@iinteractive.comE<gt>
+
+=head1 ORIGINAL COPYRIGHT AND LICENSE
+
+Copyright 2004 by Infinity Interactive, Inc.
+
+L<http://www.iinteractive.com>
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
+
 =head1 METHODS
 
 This is a subclass of Array::Iterator, only those methods that have been added or altered are documented here, refer to the Array::Iterator documentation for more information.
@@ -133,38 +148,33 @@ This method will tell you how many times the iterator has looped back to its sta
 
 =back
 
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/Array-Iterator>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/sharyanto/perl-Array-Iterator>.
+
 =head1 BUGS
 
-None that I am aware of, if you find a bug, let me know, and I will be sure to fix it.
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Array-Iterator>
 
-=head1 CODE COVERAGE
-
-See the B<CODE COVERAGE> section of the B<Array::Iterator> documentation for information about the code coverage of this module's test suite.
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
 
 =head1 SEE ALSO
 
 This is a subclass of B<Array::Iterator>, please refer to it for more documenation.
 
-=head1 ORIGINAL AUTHOR
-
-stevan little, E<lt>stevan@iinteractive.comE<gt>
-
-=head1 ORIGINAL COPYRIGHT AND LICENSE
-
-Copyright 2004 by Infinity Interactive, Inc.
-
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Steven Haryanto.
+This software is copyright (c) 2017, 2013, 2012, 2011 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
